==> haskell-netlink-1.1.1.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-netlink.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 netlink
version:              1.1.1.0
visibility:           public
id:                   netlink-1.1.1.0-9Dgd6kICj2Q7XG9MRM7S2p
key:                  netlink-1.1.1.0-9Dgd6kICj2Q7XG9MRM7S2p
license:              BSD-3-Clause
copyright:            Google Inc. 2010
maintainer:           Markus Ongyerth <ongy@ongy.net>
author:               David Anderson
stability:            Alpha
homepage:             https://github.com/Ongy/netlink-hs
synopsis:             Netlink communication for Haskell
description:          Library to comminicate with Linux kernel via Netlink
category:             System
abi:                  c2597f4dc5036ad843b9399e14a08cf2
exposed:              True
exposed-modules:
    System.Linux.Netlink System.Linux.Netlink.Constants
    System.Linux.Netlink.GeNetlink
    System.Linux.Netlink.GeNetlink.Constants
    System.Linux.Netlink.GeNetlink.Control
    System.Linux.Netlink.GeNetlink.NL80211
    System.Linux.Netlink.GeNetlink.NL80211.Constants
    System.Linux.Netlink.GeNetlink.NL80211.StaInfo
    System.Linux.Netlink.GeNetlink.NL80211.WifiEI
    System.Linux.Netlink.Helpers System.Linux.Netlink.Route
    System.Linux.Netlink.Route.LinkStat

hidden-modules:       System.Linux.Netlink.C
import-dirs:          /usr/lib/ghc-8.8.3/site-local/netlink-1.1.1.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/netlink-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/netlink-1.1.1.0
hs-libraries:         HSnetlink-1.1.1.0-9Dgd6kICj2Q7XG9MRM7S2p
depends:
    base-4.13.0.0 bytestring-0.10.10.0
    cereal-0.5.8.1-4ELvUVAvdXS1XtXORHyQWs containers-0.6.2.1
    monad-loops-0.4.3-1E2zS5vP8vC8dPxRpEhLxP
    pretty-hex-1.1-LeIcJE8JSPz4oaRdpqV604 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-netlink/html/netlink.haddock
haddock-html:         /usr/share/doc/haskell-netlink/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-netlink-1.1.1.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-netlink.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 netlink
version:              1.1.1.0
visibility:           public
id:                   netlink-1.1.1.0-4toQOB5udCl4LP2WvsUWWN
key:                  netlink-1.1.1.0-4toQOB5udCl4LP2WvsUWWN
license:              BSD-3-Clause
copyright:            Google Inc. 2010
maintainer:           Markus Ongyerth <ongy@ongy.net>
author:               David Anderson
stability:            Alpha
homepage:             https://github.com/Ongy/netlink-hs
synopsis:             Netlink communication for Haskell
description:          Library to comminicate with Linux kernel via Netlink
category:             System
abi:                  b04da88ca90fb0b4b79f2f9b574e8eed
exposed:              True
exposed-modules:
    System.Linux.Netlink System.Linux.Netlink.Constants
    System.Linux.Netlink.GeNetlink
    System.Linux.Netlink.GeNetlink.Constants
    System.Linux.Netlink.GeNetlink.Control
    System.Linux.Netlink.GeNetlink.NL80211
    System.Linux.Netlink.GeNetlink.NL80211.Constants
    System.Linux.Netlink.GeNetlink.NL80211.StaInfo
    System.Linux.Netlink.GeNetlink.NL80211.WifiEI
    System.Linux.Netlink.Helpers System.Linux.Netlink.Route
    System.Linux.Netlink.Route.LinkStat

hidden-modules:       System.Linux.Netlink.C
import-dirs:          /usr/lib/ghc-8.10.1/site-local/netlink-1.1.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/netlink-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/netlink-1.1.1.0
hs-libraries:         HSnetlink-1.1.1.0-4toQOB5udCl4LP2WvsUWWN
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    cereal-0.5.8.1-HU1Om29vBJGHr3TJypdaoY containers-0.6.2.1
    monad-loops-0.4.3-8vl2D03xZPMKQkyzzvP1nU
    pretty-hex-1.1-GrJ47rTLcMl5IENzUWyyN7 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-netlink/html/netlink.haddock
haddock-html:         /usr/share/doc/haskell-netlink/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
